==> jbrowse2-2.15.0-hbbc3ce4_0.tar.bz2: opt/jbrowse2/build_env_setup.sh <==
export CONDA_BUILD="1"
export PYTHONNOUSERSITE="1"
export CONDA_DEFAULT_ENV="/opt/conda/conda-bld/jbrowse2_1725420006304/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac"
export ARCH="64"
export PREFIX="/opt/conda/conda-bld/jbrowse2_1725420006304/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac"
export BUILD_PREFIX="/opt/conda/conda-bld/jbrowse2_1725420006304/_build_env"
export SYS_PREFIX="/opt/conda"
export SYS_PYTHON="/opt/conda/bin/python"
export SUBDIR="linux-64"
export build_platform="linux-64"
export SRC_DIR="/opt/conda/conda-bld/jbrowse2_1725420006304/work"
export ROOT="/opt/conda"
export CONDA_PY="312"
export PY3K="1"
export PY_VER="3.12"
export STDLIB_DIR="/opt/conda/conda-bld/jbrowse2_1725420006304/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/lib/python3.12"
export SP_DIR="/opt/conda/conda-bld/jbrowse2_1725420006304/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/lib/python3.12/site-packages"
export NPY_VER="1.26"
export CONDA_NPY="126"
export NPY_DISTUTILS_APPEND_FLAGS="1"
export PERL_VER="5.32"
export CONDA_PERL="5.32"
export LUA_VER="5"
export CONDA_LUA="5"
export R_VER="4.3.*"
export CONDA_R="4.3.*"
export PKG_NAME="jbrowse2"
export PKG_VERSION="2.15.0"
export PKG_BUILDNUM="0"
export PKG_BUILD_STRING="placeholder"
export PKG_HASH="1234567"
export RECIPE_DIR="/opt/recipe"
export CPU_COUNT="2"
export LANG="C.UTF-8"
export SHLIB_EXT=".so"
export PATH="/opt/conda/conda-bld/jbrowse2_1725420006304/_build_env/bin:/opt/conda/conda-bld/jbrowse2_1725420006304/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/bin:/opt/conda/bin:/opt/conda/condabin:/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/home/conda/bin"
export HOME="/home/conda"
export PKG_CONFIG_PATH="/opt/conda/conda-bld/jbrowse2_1725420006304/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/lib/pkgconfig"
export CMAKE_GENERATOR="Unix Makefiles"
export LD_RUN_PATH="/opt/conda/conda-bld/jbrowse2_1725420006304/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/lib"
export BUILD="x86_64-conda_cos6-linux-gnu"
export zip_keys="[['arrow_cpp', 'libarrow', 'libarrow_all'], ['python', 'numpy', 'python_impl'], ['c_compiler_version', 'cxx_compiler_version', 'fortran_compiler_version'], ['c_stdlib_version', 'cdt_name']]"
export extend_keys="{'ignore_version', 'extend_keys', 'pin_run_as_build', 'ignore_build_only_deps'}"
export pin_run_as_build="OrderedDict([('python', {'min_pin': 'x.x', 'max_pin': 'x.x'}), ('r-base', {'max_pin': 'x.x', 'min_pin': 'x.x'}), ('flann', {'max_pin': 'x.x.x'}), ('graphviz', {'max_pin': 'x'}), ('libsvm', {'max_pin': 'x'}), ('netcdf-cxx4', {'max_pin': 'x.x'}), ('occt', {'max_pin': 'x.x'}), ('poppler', {'max_pin': 'x.x'}), ('vlfeat', {'max_pin': 'x.x.x'})])"
export ignore_build_only_deps="{'numpy', 'python'}"
export cxx_compiler="gxx"
export libmatio="1.5.26"
export ldas_tools_framecpp="2.9"
export pyqtchart="5.15"
export libgdal="3.8"
export s2n="1.4.15"
export openmpi="4"
export flann="1.9.2"
export srm_ifce="1.24.6"
export cuda_compiler_version="None"
export coin_or_cgl="0.60"
export glew="2.1"
export starlink_ast="9.2.7"
export aws_c_compression="0.2.18"
export libgoogle_cloud_compute_devel="2.24"
export ucx="1.16.0"
export freetype="2"
export libunwind="1.6"
export mumps_mpi="5.7.1"
export proj="9.3.1"
export assimp="5.3.1"
export qt6_main="6.7"
export libgoogle_cloud_bigtable_devel="2.24"
export lcms2="2"
export libnetcdf="4.9.2"
export zlib="1.2"
export console_bridge="1.0"
export libwebp="1"
export aws_c_s3="0.5.9"
export cuda_compiler="None"
export kealib="1.5"
export libsentencepiece="0.2.0"
export orc="2.0.1"
export zstd="1.5"
export lzo="2"
export readline="8"
export libcblas="3.9 *netlib"
export libhugetlbfs="2"
export libgoogle_cloud_iam_devel="2.24"
export glog="0.6"
export exiv2="0.28"
export postgresql_plpython="16"
export dcap="2.47"
export snappy="1.2"
export VERBOSE_CM="VERBOSE=1"
export slepc="3.21"
export jasper="4"
export ptscotch="7.0.4"
export pari="2.15.* *_pthread"
export VERBOSE_AT="V=1"
export libosqp="0.6.3"
export mpich="4"
export libv8="8.9.83"
export ncurses="6"
export petsc4py="3.21"
export sdl2="2"
export vlfeat="0.9.21"
export libgoogle_cloud_storage_devel="2.24"
export gnutls="3.7"
export expat="2"
export qtkeychain="0.14"
export libtiff="4.6"
export arpack="3.8"
export nccl="2"
export gsoap="2.8.123"
export elfutils="0.191"
export gdk_pixbuf="2"
export netcdf_cxx4="4.3"
export pixman="0"
export vtk="9.2.6"
export libiio="0"
export gmp="6"
export aws_c_io="0.14.8"
export slepc4py="3.21"
export capnproto="1.0.2"
export libssh2="1"
export libframel="8.41"
export bamtools="2.5.2"
export ccr="1.3"
export libblas="3.9 *netlib"
export libabseil_static="20220623.0"
export libavif="1"
export eclib="20231211"
export libgoogle_cloud_automl_devel="2.24"
export attr="2.5"
export re2="2023.09.01"
export libzip="1"
export thrift_cpp="0.18.1"
export libtensorflow_cc="2.15"
export libgoogle_cloud_pubsub_devel="2.24"
export mpfr="4"
export libtorch="2.1"
export log4cxx="1.2.0"
export libidn2="2"
export libopenvino_dev="2024.1.0"
export aws_c_mqtt="0.10.4"
export librsvg="2"
export libwebp_base="1"
export aws_sdk_cpp="1.11.267"
export mkl="2023"
export libdap4="3.20.6"
export cran_mirror="https://cran.r-project.org"
export googleapis_cpp="0.10"
export ntl="11.4.3"
export libgoogle_cloud_devel="2.24"
export libmatio_cpp="0.2.5"
export glib="2"
export nodejs="20"
export c_ares="1"
export libjpeg_turbo="3"
export aws_checksums="0.1.18"
export liblapack="3.9 *netlib"
export cfitsio="4.3.0"
export gdal="3.8"
export zeromq="4.3.5"
export libpq="16"
export r_base="4.3.*"
export gst_plugins_base="1.22"
export gnuradio_core="3.10.10"
export libaec="1"
export libblitz="1.0.2"
export fortran_compiler="gfortran"
export postgresql="16"
export zfp="1.0"
export davix="0.8"
export libopentelemetry_cpp="1.15"
export antic="0.2"
export libgoogle_cloud_dialogflow_cx_devel="2.24"
export metis="5.1.0"
export rocksdb="9.1"
export _libgcc_mutex="0.1 conda_forge"
export cuda_compiler_version_min="11.8"
export target_goarch="amd64"
export ffmpeg="6"
export libhwy="1.1"
export libgoogle_cloud_dialogflow_es_devel="2.24"
export libuuid="2"
export libsvm="332"
export ruby="2.6"
export wcslib="8"
export libcurl="8"
export target_goos="linux"
export blas_impl="blis"
export cairo="1"
export sdl2_net="2"
export target_gobin="${PREFIX}/bin/"
export libflint="2.9"
export scotch="7.0.4"
export c_blosc2="2.14"
export jsoncpp="1.9.5"
export libgoogle_cloud_policytroubleshooter_devel="2.24"
export libspatialindex="1.9.3"
export libgrpc="1.62"
export pyqtwebengine="5.15"
export libmicrohttpd="1.0"
export bullet_cpp="3.25"
export mkl_devel="2023"
export openexr="3.2"
export libptscotch="7.0.4"
export libeantic="2"
export libboost_python_devel="1.82"
export libiconv="1"
export gf2x="1.3"
export pulseaudio="17.0"
export c_stdlib="sysroot"
export sqlite="3"
export nettle="3.9"
export dbus="1"
export openblas="0.3.*"
export pulseaudio_daemon="17.0"
export libprotobuf="4.25.3"
export pcl="1.14.0"
export libxsmm="1"
export harfbuzz="8"
export libarchive="3.7"
export pcre2="10.43"
export pango="1.50"
export svt_av1="2.1.0"
export libsecret="0.18"
export libthrift="0.20.0"
export tensorflow="2.15"
export mpg123="1.32"
export msgpack_cxx="6"
export sdl2_ttf="2"
export alsa_lib="1.2"
export hdf5="1.14.3"
export libabseil="20240116"
export x264="1!164.*"
export krb5="1.21"
export librdkafka="2.4"
export icu="73"
export libvips="8"
export nspr="4"
export libevent="2.1.12"
export jpeg="9"
export aws_crt_cpp="0.26.9"
export xz="5"
export poppler="24.04"
export libsqlite="3"
export libxml2="2"
export giflib="5.2"
export libgoogle_cloud_all_devel="2.24"
export libpcap="1.10"
export dav1d="1.2.1"
export p11_kit="0.24"
export aws_c_sdkutils="0.1.16"
export libssh="0.10"
export cutensor="2"
export netcdf_fortran="4.6"
export libev="4.33"
export coin_or_utils="2.11"
export libkml="1.3"
export glpk="5.0"
export grpc_cpp="1.52"
export arb="2.23"
export urdfdom="4.0"
export libboost_devel="1.82"
export cpu_optimization_target="nocona"
export superlu_dist="8"
export graphviz="9"
export openh264="2.4.1"
export tinyxml2="10"
export aws_c_cal="0.6.14"
export libsndfile="1.2"
export coin_or_clp="1.17"
export rdma_core="51"
export target_platform="linux-64"
export coin_or_cbc="2.10"
export pyqt="5.15"
export liblapacke="3.9 *netlib"
export fftw="3"
export zlib_ng="2.0"
export poco="1.13.3"
export lmdb="0.9.29"
export libgoogle_cloud="2.24"
export ipopt="3.14.16"
export sdl2_image="2"
export libgoogle_cloud_oauth2_devel="2.24"
export libgoogle_cloud_discoveryengine_devel="2.24"
export openjpeg="2"
export libscotch="7.0.4"
export volk="3.1"
export pcre="8"
export libgoogle_cloud_speech_devel="2.24"
export tbb="2021"
export lz4_c="1.9.3"
export imath="3.1.11"
export libgoogle_cloud_dlp_devel="2.24"
export singular="4.3.2.p8"
export aws_c_http="0.8.1"
export channel_targets="bioconda main"
export libexactreal="4"
export aom="3.8"
export libpng="1.6"
export fmt="10"
export libflatsurf="3"
export hdf4="4.2.15"
export fontconfig="2"
export libintervalxt="3"
export pulseaudio_client="17.0"
export sox="14.4.2"
export flatbuffers="24.3.25"
export uhd="4.6.0"
export geos="3.12.1"
export gflags="2.2"
export libgoogle_cloud_spanner_devel="2.24"
export msgpack_c="6"
export cudnn="8"
export cgo_compiler="go-cgo"
export libraw="0.21"
export aws_c_common="0.9.19"
export libdeflate="1.20"
export petsc="3.21"
export libopencv="4.9.0"
export wxwidgets="3.2"
export lerc="4"
export coin_or_osi="0.108"
export qt_main="5.15"
export libsoup="3"
export libhwloc="2.10.0"
export gfal2="2.22"
export gsl="2.7"
export libtensorflow="2.15"
export idyntree="12"
export rust_compiler="rust"
export mimalloc="2.1.7"
export c_compiler="gcc"
export geotiff="1.7.1"
export pybind11_abi="4"
export libyarp="3.9.0"
export openslide="4"
export go_compiler="go-nocgo"
export gstreamer="1.22"
export google_cloud_cpp_common="0.25.0"
export tiledb="2.23"
export pytorch="2.1"
export suitesparse="5"
export libgoogle_cloud_aiplatform_devel="2.24"
export nlopt="2.7"
export x265="3.5"
export bzip2="1"
export libduckdb_devel="0.9.2"
export libgoogle_cloud_bigquery_devel="2.24"
export xerces_c="3.2"
export coincbc="2.10"
export aws_c_event_stream="0.4.2"
export spdlog="1.12"
export soapysdr="0.8"
export libgit2="1.8"
export aws_c_auth="0.7.22"
export libode="0.16.2"
export libcrc32c="1.1"
export mumps_seq="5.7.1"
export sdl2_mixer="2"
export xrootd="5"
export libmed="4.1"
export openssl="3"
export qt="5.15"
export libcint="5.5"
export tk="8.6"
export google_cloud_cpp="2.24"
export occt="7.7.2"
export channel_sources="conda-forge,bioconda"
export curl="8"
export tbb_devel="2021"
export libffi="3.4"
export json_c="0.17"
export pugixml="1.14"
export root_base="6.28.10"
export gct="6.2.1705709074"
export isl="0.26"
export abseil_cpp="20220623.0"
export nss="3"
export cxx_compiler_version="12"
export fortran_compiler_version="12"
export c_compiler_version="12"
export c_stdlib_version="2.17"
export cdt_name="cos6"
export python_impl="cpython"
export libarrow_all="14"
export arrow_cpp="14"
export libarrow="14"
export CONDA_BUILD_STATE="BUILD"
export PIP_NO_BUILD_ISOLATION="False"
export PIP_NO_DEPENDENCIES="True"
export PIP_IGNORE_INSTALLED="True"
export PIP_CACHE_DIR="/opt/conda/conda-bld/jbrowse2_1725420006304/pip_cache"
export PIP_NO_INDEX="True"
eval "$('/opt/conda/bin/python' -m conda shell.bash hook)"
conda activate "/opt/conda/conda-bld/jbrowse2_1725420006304/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac"
conda activate --stack "/opt/conda/conda-bld/jbrowse2_1725420006304/_build_env"

==> jbrowse2-2.15.4-hbbc3ce4_0.tar.bz2: opt/jbrowse2/build_env_setup.sh <==
export CONDA_BUILD="1"
export PYTHONNOUSERSITE="1"
export CONDA_DEFAULT_ENV="/opt/conda/conda-bld/jbrowse2_1726856947541/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac"
export ARCH="64"
export PREFIX="/opt/conda/conda-bld/jbrowse2_1726856947541/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac"
export BUILD_PREFIX="/opt/conda/conda-bld/jbrowse2_1726856947541/_build_env"
export SYS_PREFIX="/opt/conda"
export SYS_PYTHON="/opt/conda/bin/python"
export SUBDIR="linux-64"
export build_platform="linux-64"
export SRC_DIR="/opt/conda/conda-bld/jbrowse2_1726856947541/work"
export ROOT="/opt/conda"
export CONDA_PY="312"
export PY3K="1"
export PY_VER="3.12"
export STDLIB_DIR="/opt/conda/conda-bld/jbrowse2_1726856947541/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/lib/python3.12"
export SP_DIR="/opt/conda/conda-bld/jbrowse2_1726856947541/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/lib/python3.12/site-packages"
export NPY_VER="1.26"
export CONDA_NPY="126"
export NPY_DISTUTILS_APPEND_FLAGS="1"
export PERL_VER="5.32"
export CONDA_PERL="5.32"
export LUA_VER="5"
export CONDA_LUA="5"
export R_VER="4.3.*"
export CONDA_R="4.3.*"
export PKG_NAME="jbrowse2"
export PKG_VERSION="2.15.4"
export PKG_BUILDNUM="0"
export PKG_BUILD_STRING="placeholder"
export PKG_HASH="1234567"
export RECIPE_DIR="/opt/recipe"
export CPU_COUNT="2"
export LANG="C.UTF-8"
export SHLIB_EXT=".so"
export PATH="/opt/conda/conda-bld/jbrowse2_1726856947541/_build_env/bin:/opt/conda/conda-bld/jbrowse2_1726856947541/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/bin:/opt/conda/bin:/opt/conda/condabin:/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/home/conda/bin"
export HOME="/home/conda"
export PKG_CONFIG_PATH="/opt/conda/conda-bld/jbrowse2_1726856947541/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/lib/pkgconfig"
export CMAKE_GENERATOR="Unix Makefiles"
export LD_RUN_PATH="/opt/conda/conda-bld/jbrowse2_1726856947541/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/lib"
export BUILD="x86_64-conda_cos6-linux-gnu"
export zip_keys="[['c_compiler_version', 'cxx_compiler_version', 'fortran_compiler_version'], ['arrow_cpp', 'libarrow', 'libarrow_all'], ['python', 'numpy', 'python_impl'], ['c_stdlib_version', 'cdt_name']]"
export pin_run_as_build="OrderedDict([('python', {'min_pin': 'x.x', 'max_pin': 'x.x'}), ('r-base', {'max_pin': 'x.x', 'min_pin': 'x.x'}), ('flann', {'max_pin': 'x.x.x'}), ('graphviz', {'max_pin': 'x'}), ('libsvm', {'max_pin': 'x'}), ('netcdf-cxx4', {'max_pin': 'x.x'}), ('occt', {'max_pin': 'x.x'}), ('poppler', {'max_pin': 'x.x'}), ('vlfeat', {'max_pin': 'x.x.x'})])"
export extend_keys="{'ignore_version', 'pin_run_as_build', 'extend_keys', 'ignore_build_only_deps'}"
export ignore_build_only_deps="{'python', 'numpy'}"
export libyarp="3.9.0"
export libintervalxt="3"
export tk="8.6"
export libmatio="1.5.26"
export qt="5.15"
export coin_or_cgl="0.60"
export coincbc="2.10"
export pixman="0"
export libhugetlbfs="2"
export libopencv="4.9.0"
export ccr="1.3"
export superlu_dist="8"
export libsoup="3"
export pyqtwebengine="5.15"
export hdf4="4.2.15"
export gst_plugins_base="1.22"
export eclib="20231211"
export google_cloud_cpp_common="0.25.0"
export dcap="2.47"
export slepc4py="3.21"
export scotch="7.0.4"
export snappy="1.2"
export suitesparse="5"
export libblitz="1.0.2"
export libabseil_static="20220623.0"
export libflatsurf="3"
export pulseaudio="17.0"
export libcblas="3.9 *netlib"
export libgoogle_cloud_dlp_devel="2.24"
export rocksdb="9.1"
export _libgcc_mutex="0.1 conda_forge"
export gnuradio_core="3.10.10"
export librdkafka="2.4"
export libdap4="3.20.6"
export aws_c_auth="0.7.22"
export channel_targets="bioconda main"
export libhwloc="2.10.0"
export pyqt="5.15"
export cpu_optimization_target="nocona"
export assimp="5.3.1"
export mpfr="4"
export pcre2="10.43"
export gsl="2.7"
export ptscotch="7.0.4"
export xrootd="5"
export arpack="3.8"
export cxx_compiler="gxx"
export sdl2_net="2"
export target_goos="linux"
export elfutils="0.191"
export libhwy="1.1"
export uhd="4.6.0"
export petsc="3.21"
export pulseaudio_daemon="17.0"
export libeantic="2"
export libopentelemetry_cpp="1.15"
export bamtools="2.5.2"
export openblas="0.3.*"
export icu="73"
export libiio="0"
export x264="1!164.*"
export mpich="4"
export pybind11_abi="4"
export nettle="3.9"
export libwebp_base="1"
export abseil_cpp="20220623.0"
export thrift_cpp="0.18.1"
export openmpi="4"
export coin_or_cbc="2.10"
export openslide="4"
export libscotch="7.0.4"
export sdl2_mixer="2"
export fontconfig="2"
export libgoogle_cloud_oauth2_devel="2.24"
export grpc_cpp="1.52"
export libmatio_cpp="0.2.5"
export libboost_python_devel="1.82"
export openh264="2.4.1"
export pcre="8"
export vlfeat="0.9.21"
export mumps_seq="5.7.1"
export gct="6.2.1705709074"
export openssl="3"
export dbus="1"
export googleapis_cpp="0.10"
export xz="5"
export coin_or_clp="1.17"
export libcurl="8"
export aws_checksums="0.1.18"
export libtensorflow="2.15"
export libidn2="2"
export aws_c_common="0.9.19"
export google_cloud_cpp="2.24"
export libsqlite="3"
export libthrift="0.20.0"
export ucx="1.16.0"
export re2="2023.09.01"
export c_compiler="gcc"
export zlib="1.2"
export gnutls="3.7"
export aws_sdk_cpp="1.11.267"
export mpg123="1.32"
export libevent="2.1.12"
export go_compiler="go-nocgo"
export libarchive="3.7"
export msgpack_c="6"
export ntl="11.4.3"
export davix="0.8"
export libev="4.33"
export ruby="2.6"
export glog="0.6"
export libopenvino_dev="2024.1.0"
export exiv2="0.28"
export libpng="1.6"
export ncurses="6"
export lz4_c="1.9.3"
export libzip="1"
export sqlite="3"
export postgresql_plpython="16"
export libprotobuf="4.25.3"
export gdal="3.8"
export libcint="5.5"
export geos="3.12.1"
export qt6_main="6.7"
export libgdal="3.8"
export occt="7.7.2"
export lcms2="2"
export librsvg="2"
export libgoogle_cloud_bigquery_devel="2.24"
export libffi="3.4"
export tinyxml2="10"
export zstd="1.5"
export fmt="10"
export libframel="8.41"
export libgoogle_cloud_dialogflow_cx_devel="2.24"
export jsoncpp="1.9.5"
export libgoogle_cloud_dialogflow_es_devel="2.24"
export target_platform="linux-64"
export gflags="2.2"
export aws_c_sdkutils="0.1.16"
export aws_c_http="0.8.1"
export netcdf_cxx4="4.3"
export libjpeg_turbo="3"
export sox="14.4.2"
export VERBOSE_CM="VERBOSE=1"
export jasper="4"
export coin_or_osi="0.108"
export spdlog="1.12"
export libgoogle_cloud_automl_devel="2.24"
export libtorch="2.1"
export libgrpc="1.62"
export libgit2="1.8"
export readline="8"
export jpeg="9"
export libmicrohttpd="1.0"
export pari="2.15.* *_pthread"
export libv8="8.9.83"
export cuda_compiler_version="None"
export openexr="3.2"
export nspr="4"
export libssh2="1"
export urdfdom="4.0"
export tiledb="2.23"
export aws_c_compression="0.2.18"
export coin_or_utils="2.11"
export zeromq="4.3.5"
export libgoogle_cloud_policytroubleshooter_devel="2.24"
export metis="5.1.0"
export libraw="0.21"
export libpq="16"
export mimalloc="2.1.7"
export svt_av1="2.1.0"
export libpcap="1.10"
export curl="8"
export lzo="2"
export idyntree="12"
export x265="3.5"
export c_blosc2="2.14"
export libiconv="1"
export slepc="3.21"
export libflint="2.9"
export libgoogle_cloud_compute_devel="2.24"
export libvips="8"
export nlopt="2.7"
export gstreamer="1.22"
export libtensorflow_cc="2.15"
export cutensor="2"
export aws_c_s3="0.5.9"
export c_stdlib="sysroot"
export libode="0.16.2"
export zlib_ng="2.0"
export geotiff="1.7.1"
export libsecret="0.18"
export libabseil="20240116"
export hdf5="1.14.3"
export libmed="4.1"
export netcdf_fortran="4.6"
export libptscotch="7.0.4"
export libcrc32c="1.1"
export glew="2.1"
export kealib="1.5"
export sdl2_image="2"
export channel_sources="conda-forge,bioconda"
export harfbuzz="8"
export nodejs="20"
export libduckdb_devel="0.9.2"
export pytorch="2.1"
export pulseaudio_client="17.0"
export aws_crt_cpp="0.26.9"
export pango="1.50"
export alsa_lib="1.2"
export bzip2="1"
export tbb="2021"
export root_base="6.28.10"
export libnetcdf="4.9.2"
export cran_mirror="https://cran.r-project.org"
export wxwidgets="3.2"
export orc="2.0.1"
export singular="4.3.2.p8"
export libspatialindex="1.9.3"
export p11_kit="0.24"
export cuda_compiler="None"
export log4cxx="1.2.0"
export cuda_compiler_version_min="11.8"
export msgpack_cxx="6"
export libxml2="2"
export fftw="3"
export libuuid="2"
export wcslib="8"
export VERBOSE_AT="V=1"
export cudnn="8"
export mkl="2023"
export ldas_tools_framecpp="2.9"
export libgoogle_cloud_aiplatform_devel="2.24"
export pyqtchart="5.15"
export qtkeychain="0.14"
export blas_impl="blis"
export nss="3"
export gdk_pixbuf="2"
export gf2x="1.3"
export tensorflow="2.15"
export liblapacke="3.9 *netlib"
export libgoogle_cloud_spanner_devel="2.24"
export pcl="1.14.0"
export krb5="1.21"
export libsvm="332"
export libexactreal="4"
export cgo_compiler="go-cgo"
export petsc4py="3.21"
export poppler="24.04"
export aws_c_event_stream="0.4.2"
export vtk="9.2.6"
export libkml="1.3"
export libssh="0.10"
export flann="1.9.2"
export gfal2="2.22"
export cfitsio="4.3.0"
export s2n="1.4.15"
export rdma_core="51"
export json_c="0.17"
export zfp="1.0"
export libgoogle_cloud_devel="2.24"
export giflib="5.2"
export soapysdr="0.8"
export libblas="3.9 *netlib"
export openjpeg="2"
export mkl_devel="2023"
export imath="3.1.11"
export glib="2"
export libboost_devel="1.82"
export target_gobin="${PREFIX}/bin/"
export libsentencepiece="0.2.0"
export pugixml="1.14"
export antic="0.2"
export libgoogle_cloud_bigtable_devel="2.24"
export sdl2="2"
export ipopt="3.14.16"
export mumps_mpi="5.7.1"
export qt_main="5.15"
export c_ares="1"
export volk="3.1"
export libgoogle_cloud_pubsub_devel="2.24"
export aws_c_cal="0.6.14"
export ffmpeg="6"
export libunwind="1.6"
export gmp="6"
export sdl2_ttf="2"
export capnproto="1.0.2"
export isl="0.26"
export libgoogle_cloud_iam_devel="2.24"
export libaec="1"
export tbb_devel="2021"
export xerces_c="3.2"
export liblapack="3.9 *netlib"
export cairo="1"
export libtiff="4.6"
export aws_c_io="0.14.8"
export dav1d="1.2.1"
export lerc="4"
export target_goarch="amd64"
export proj="9.3.1"
export arb="2.23"
export aws_c_mqtt="0.10.4"
export libgoogle_cloud_speech_devel="2.24"
export expat="2"
export bullet_cpp="3.25"
export srm_ifce="1.24.6"
export libgoogle_cloud_storage_devel="2.24"
export libavif="1"
export postgresql="16"
export glpk="5.0"
export graphviz="9"
export lmdb="0.9.29"
export flatbuffers="24.3.25"
export libxsmm="1"
export freetype="2"
export console_bridge="1.0"
export libgoogle_cloud="2.24"
export aom="3.8"
export rust_compiler="rust"
export libgoogle_cloud_all_devel="2.24"
export libdeflate="1.20"
export nccl="2"
export libgoogle_cloud_discoveryengine_devel="2.24"
export attr="2.5"
export gsoap="2.8.123"
export starlink_ast="9.2.7"
export fortran_compiler="gfortran"
export r_base="4.3.*"
export libwebp="1"
export libsndfile="1.2"
export poco="1.13.3"
export libosqp="0.6.3"
export arrow_cpp="15"
export libarrow="15"
export libarrow_all="15"
export python_impl="cpython"
export c_stdlib_version="2.17"
export cdt_name="cos6"
export c_compiler_version="12"
export cxx_compiler_version="12"
export fortran_compiler_version="12"
export CONDA_BUILD_STATE="BUILD"
export PIP_NO_BUILD_ISOLATION="False"
export PIP_NO_DEPENDENCIES="True"
export PIP_IGNORE_INSTALLED="True"
export PIP_CACHE_DIR="/opt/conda/conda-bld/jbrowse2_1726856947541/pip_cache"
export PIP_NO_INDEX="True"
eval "$('/opt/conda/bin/python' -m conda shell.bash hook)"
conda activate "/opt/conda/conda-bld/jbrowse2_1726856947541/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac"
conda activate --stack "/opt/conda/conda-bld/jbrowse2_1726856947541/_build_env"
